Installation — Football Packing 0.1 documentation

# Installation

## Install

The package can be installed from PyPI or from GitHub.

## Versioned

Install a specific version (where <VERSION> is something like ‘0.1’) from PyPi:

    pip install football_packing==0.1

or from GitHub:

    pip install git+https://github.com/samirak93/Football-packing

## Dependencies

Package | Minimum supported version
--- | ---
Pandas | >=1.0.3
NumPy | >=1.18.1
Bokeh | >=2.0.2
Scipy | >=1.4.1
Scikit-learn | >=0.23.1